TxLocalState

Type Alias TxLocalState 

pub type TxLocalState = BTreeMap<ContractId, BTreeMap<[u8; 32], BTreeMap<Vec<u8>, Vec<u8>>>>;
Transaction-local state db.

This is an in-memory BTreeMap that works equivalently to the existing blockchain DB in contracts, except its lifetime is during a single transaction execution.

Aliased Type

pub struct TxLocalState { /* private fields */ }